@@ -309,6 +309,14 @@ class APK:
         if not skip_analysis:
             self._apk_analysis()
 
+    def __repr__(self):
+        repr = """
+        filename: {self.filename}
+        package: {self.package}
+        valid apk: {self.valid_apk}
+        """
+        return repr
+
     def _ns(self, name):
         """
         return the name including the Android namespace
@@ -786,7 +794,7 @@ class APK:
 
         :rtype: a list of str
         """
-        dexre = re.compile("classes(\d*).dex")
+        dexre = re.compile(r"classes(\d*).dex")
         return filter(lambda x: dexre.match(x), self.get_files())
 
     def get_all_dex(self):
@@ -804,7 +812,7 @@ class APK:
 
         :return: True if multiple dex found, otherwise False
         """
-        dexre = re.compile("^classes(\d+)?.dex$")
+        dexre = re.compile(r"^classes(\d+)?.dex$")
         return len([instance for instance in self.get_files() if dexre.search(instance)]) > 1
 
     @DeprecationWarning
@@ -1003,7 +1011,7 @@ class APK:
         ]
 
     def is_tag_matched(self, tag, **attribute_filter):
-        """
+        r"""
         Return true if the attributes matches in attribute filter.
 
         An attribute filter is a dictionary containing: {attribute_name: value}.
